simplify.BadRequestError

Package simplify :: Class BadRequestError |
[hide private]
[frames] | no frames]

# Class BadRequestError

source code

                  object --+
                           |
    exceptions.BaseException --+
                               |
            exceptions.Exception --+
                                   |
                            ApiError --+
                                       |
                                      BadRequestError

Error raised when the request contains errors.

Nested Classes | [hide private]
| FieldError Represents a single error in a field of data sent in a request to the API.

Instance Methods | [hide private]
__init__(self, message, status=400, error_data=None) x.__init__(...) initializes x; see help(type(x)) for signature | source code
describe(self) Returns a string describing the error. | source code
Inherited from `exceptions.Exception`: `__new__` Inherited from `exceptions.BaseException`: `__delattr__`, `__getattribute__`, `__getitem__`, `__getslice__`, `__reduce__`, `__repr__`, `__setattr__`, `__setstate__`, `__str__`, `__unicode__` Inherited from `object`: `__format__`, `__hash__`, `__reduce_ex__`, `__sizeof__`, `__subclasshook__`

Instance Variables | [hide private]
| field_errors a list containing all field errors.
| has_field_errors boolean indicating whether there are field errors.
Inherited from `ApiError`: `error_code`, `error_data`, `message`, `reference`, `status`

Properties | [hide private]
Inherited from `exceptions.BaseException`: `args` Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, message, status=400, error_data=None) (Constructor) | source code
x.__init__(...) initializes x; see help(type(x)) for signature Overrides: object.__init__ (inherited documentation)

### describe(self) | source code
Returns a string describing the error. Returns: a string describing the error. Overrides: ApiError.describe